@@ -1,7 +1,9 @@
 package Sah::Schema::currency::code;
 
-our $DATE = '2019-11-29'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-03-02'; # DATE
+our $DIST = 'Sah-Schemas-Currency'; # DIST
+our $VERSION = '0.004'; # VERSION
 
 use Locale::Codes::Currency_Codes ();
 
@@ -13,12 +15,17 @@ our $schema = [str => {
     summary => 'Currency code',
     description => <<'_',
 
-Accept only current (not retired) codes.
+Accept only current (not retired) codes. Code will be converted to uppercase.
 
 _
     match => '\A[A-Z]{3}\z',
     in => $codes,
     'x.perl.coerce_rules' => ['From_str::to_upper'],
+    examples => [
+        {data=>'', valid=>0},
+        {data=>'idr', valid=>1, res=>'IDR'},
+        {data=>'foo', valid=>0},
+    ],
 }, {}];
 
 1;
@@ -36,11 +43,11 @@ Sah::Schema::currency::code - Currency code
 
 =head1 VERSION
 
-This document describes version 0.003 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2019-11-29.
+This document describes version 0.004 of Sah::Schema::currency::code (from Perl distribution Sah-Schemas-Currency), released on 2020-03-02.
 
 =head1 DESCRIPTION
 
-Accept only current (not retired) codes.
+Accept only current (not retired) codes. Code will be converted to uppercase.
 
 =head1 HOMEPAGE
 
@@ -64,7 +71,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
